@@ -539,8 +539,10 @@ def crms_pull(arg_model_url, arg_version, arg_target='', verbose=False):
         repo = Repo.clone_from(modified_model_url, target )
 
         if arg_version == 'latest' : 
+            cwd = os.getcwd()
             os.chdir(target)
             p = subprocess.run(["dvc", "pull"])
+            os.chdir(cwd)
             if p.returncode == 0 : # success of subprocess.run
                 print_verbose(verbose,"Pulled model files from DVC to " + target)
             else: # fail of subprocess.run
@@ -550,8 +552,10 @@ def crms_pull(arg_model_url, arg_version, arg_target='', verbose=False):
             past_branch = repo.create_head('crms_target', arg_version)
             repo.heads.crms_target.checkout()
 
+            cwd = os.getcwd()
             os.chdir(target)
             p = subprocess.run(["dvc", "pull"])
+            os.chdir(cwd)
             if p.returncode == 0 : # success of subprocess.run
                 print_verbose(verbose,"Pulled model files from DVC to " + target)
             else: # fail of subprocess.run
